/* Extend Rock File 06-17-09 */
/* Extend_Rock.x */

    /************************************************************************************/
    /*                                                                              	*/
    /* Description   	: This file will located the rock surface and extend the    	*/
    /*			surface out to the edge of the cross section.  it does      	*/
    /*			this by tracing the existing ground and offset that surface 	*/
    /*			down to the rock surface.					*/	
    /*											*/
    /*			If no rock is found this criteria will draw in a dunny rock	*/
    /*			surface 50 ft below exisitng ground				*/
    /*											*/
    /*			This criteria will also draw in the excavation Limit Lines	*/
    /*			for each cross section						*/
    /*											*/
    /*                                                                              	*/
    /* User Definable Variable Definitions:                                         	*/
    /*                                                                              	*/
    /*                                                                              	*/
    /*          "Cross Section DGN" --> Name of the cross section drawing.          	*/
    /*                                                                              	*/
    /* Additional Notes:                                                            	*/
    /*                  The user will need to make sure the Top of Rock symbology	*/
    /*                  match up with the define_dgn variables in this file.        	*/
    /*                  Also make sure the exsiting ground line matches the         	*/
    /*                  define_dgn for existing ground.  Lastly, this criteria      	*/
    /*                  is to ran from side slope left ONLY.                        	*/
    /*                                                                              	*/
    /*                                                                              	*/
    /* Points Marked in this file:                                                  	*/
    /*  1,2,10,997,998,999                                                          	*/
    /*                                                                              	*/
    /* Points Required from other files: None                                           */
    /*                                                                              	*/
    /************************************************************************************/

define "Cross Section DGN" xs.dgn
define "~Rock Top new symbology" wt=3 co=2 lc=2 lvname=XS-Existing traced-rock line
define "~Excavation Limits" wt=3 co=0 lc=0 lvname=Scratch-5 
 
/*********************** Plan DGN Variables *****************************/

/* Cross Section Existing Ground Symbology and Drawing Name */
define_dgn "~existing ground" \
dgn = "Cross Section DGN" \
/*ddb = $(GPK_ACBOOK_DDBFILE) \                                                */
/*feature = Design Standards/Cross Sections/Existing Surfaces/Ground Existing    */   
lvname = Modeling-Terrain-Existing \
co = 66



/* Cross Section Existing Top of Rock Symbology and Drawing Name */
define_dgn "~Rock Top" \
dgn = "Cross Section DGN" \
lvname = level 58,XS-Existing subsurface-rock, Modeling-Rock Surface-Existing \
co = 2,5,8,78
    
    if (p1) then
      {
        remove skew effect
        _d_SpacingIncrement = 1      /* Distance in feet */
        draw skip trace in off=0 for dx=1000 /* far right edge of ground */
        mark x998 y998
        draw skip trace out off=0 for dx=1000 /* far left edge of ground */
        mark x999 y999
        draw skip trace in off=0 for dx=_d_SpacingIncrement
        mark x997 y997
        draw skip to x998 y998
        _d_NumberOfSurfacesUsed = 1
        
        _s_rock_found = ^no^
      }
    
    /* Begin Trace of Rock Top */
    if (_d_NumberOfSurfacesUsed >= 1) then
      {
        mark x990 y990
        while x990 > x997
          {
            if (material below = "~Rock Top") then
              {
                /* Found beginning point */
                _s_rock_found = ^yes^
                set plot parameters "~Rock Top new symbology"
                draw skip dx=2*tolerance dy=-1 to xs "~Rock Top"
                mark x10 y10
                draw skip trace "~Rock Top" in off=0 for dx=2*_d_SpacingIncrement
                mark x1 y1  /* beginning of first instance */
                draw skip trace "~Rock Top" out off=0 for dx=1000
                mark x2 y2
		draw trace out off = elevation difference for dx = 9999
                draw skip to x1 y1
		draw trace in off = elevation difference for dx = 9999
		set plot parameters "~Excavation Limits"
		draw skip to x999 y999     /* Drawing Right Excavation Line */
		draw skip dx=-10 dy = 0
		draw skip dx=0 dy = 60
		draw dx=0 dy = -120
		draw skip to x998 y998     /* Drawing Left Excavation Line */
		draw skip dx=10 dy = 0
		draw skip dx=0 dy = 60
		draw dx=0 dy = -120
		
		draw skip to x999 y999
              }   
            draw skip trace out off=0 for dx=_d_SpacingIncrement
            mark x990 y990
          }
              
        draw skip to x998 y998
        /* Draw rock line for earthwork purposes on sections where no rock line was found and user specifies for it to be drawn. */
        if (_s_rock_found = ^no^) then
          {
            draw skip dx=0 dy=-50
            set plot parameters "~Rock Top new symbology"
            draw trace out off = elevation difference for dx = 9999
            /* draw dx=1 dy=0 to x999 */
            
            set plot parameters "~Excavation Limits"
	    draw skip to x999 y999     /* Drawing Right Excavation Line */
	    draw skip dx=-10 dy = 0
	    draw skip dx=0 dy = 60
	    draw dx=0 dy = -120
	    draw skip to x998 y998     /* Drawing Left Excavation Line */
	    draw skip dx=10 dy = 0
	    draw skip dx=0 dy = 60
	    draw dx=0 dy = -120
                        
            draw skip to x998 y998
          }  
      }
    
