<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>

    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <title lang="en">Horizontal Alignment Curve Set Review Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <h2 lang="en">MoDOT Horizontal and Vertical Alignment Review Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/>
                                    <br/>
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>

                            <xsl:for-each select="GeometryProject">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Project:&#xa0; </th>
                                            <td align="left" colspan="2">
                                                <xsl:value-of select="@name"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">File Name:&#xa0; </th>
                                            <td align="left" colspan="2">
                                                <xsl:value-of select="@file"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Last Revised:&#xa0; </th>
                                            <td align="left" colspan="2">
                                                <xsl:value-of select="concat(@lastRevisedBy, '  ', @lastRevisedDate)"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">&#xa0; </th>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>

                                <table class="margin" width="90%">
                                    <colgroup span="5">
                                        <col width="30%"/>
                                        <col width="1%"/>
                                        <col width="25%"/>
                                        <col width="22%"/>
                                        <col width="22%"/>
                                    </colgroup>

                                    <xsl:for-each select="HorizontalAlignment[HorizontalCurveSets]">
									
                                        <tbody>
                                            <tr>
                                                <th align="right" colspan="2" lang="en">Horizontal Alignment Name:&#xa0;</th>
                                                <td align="left" colspan="3" valign="bottom">
                                                    <xsl:value-of select="@name"/>
                                                </td>
                                            </tr>
									
									<xsl:for-each select="VerticalAlignment">
                                                <tr>
                                                    <th align="right" colspan="2" lang="en"><br/>Vertical Alignment:&#xa0;</th>
                                                    <td align="left" colspan="3" valign="bottom"><xsl:value-of select="@name"/></td>
                                                </tr>
                                            <tr>									
                                                <th/>
                                                <th/>
                                                <th align="right" class="underline" lang="en">Station</th>
                                                <th align="right" class="underline" lang="en"></th>
                                                <th align="right" class="underline" lang="en"></th>
                                            </tr>
                                            <tr>
                                                <td colspan="5">&#xa0;</td>
                                            </tr>
									</xsl:for-each>
									<xsl:apply-templates/>
									</tbody>
                                    </xsl:for-each>
                                </table>
								
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>

    <xsl:template match="CurvesetPoint[@pointType != 'PI']">
        <xsl:choose>
            <xsl:when test="@pointType = 'POB'">
                <tr>
                    <td align="left" lang="en">
Point of Beginning

                        (<xsl:value-of select="inr:pointType(string(GeometryPoint/@pointType))"/>)
                    </td>
                    <td align="right">
                    </td>
                    <td align="right">
                        <xsl:value-of select="inr:stationFormat(number(GeometryPoint/station/@externalStation), $xslStationFormat,$xslStationPrecision,
                                                                string(GeometryPoint/station/@externalStationName))"/>
                    </td>
                </tr>
            </xsl:when>

            <xsl:when test="@pointType = 'POE'">
                <tr>
                    <td align="left" lang="en">
Point of End

                        (<xsl:value-of select="inr:pointType(string(GeometryPoint/@pointType))"/>)
                    </td>
                    <td align="right">
                    </td>
                    <td align="right">
                        <xsl:value-of select="inr:stationFormat(number(GeometryPoint/station/@externalStation), $xslStationFormat,$xslStationPrecision,
                                                                string(GeometryPoint/station/@externalStationName))"/>
																
                    </td>
					
                </tr>
            </xsl:when>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must select at least one Civil horizontal geometry element to get results from this report.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2015 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
