<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Roadway Setup Report -->
	    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Corridor Dependency Report for Sorting in Excel</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads/RoadwayDesigner">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Critical Corridor Control Point Dependencies</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br/>
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Roadway Designer Data -->
                            <!-- <xsl:for-each select="RoadwayDesigner"> -->
                                <table class="margin" cellpadding="2">
                                    <tbody>
                                        <tr>
                                            <th align="left" lang="en">File Name:&#xa0; </th>
                                            <td align="left"><xsl:value-of select="@fileName"/></td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>
								<table class="margin" colspan="6" width="90%">
									<thead style="display:table-header-group">
									   <tr>
											<th  lang="en" align="left">Corridor           </th>
											<th  lang="en" align="left">Point Control - Corridor Reference</th>
											<th  lang="en" align="left">Clipping Corridors - Corridor Reference</th>
											<th  lang="en" align="left">Target Aliasing - Corridor Reference</th>
											<th  lang="en" align="left">End Condition Target - Corridor Reference</th>
											<th  lang="en" align="left">Point Style Target</th>
										</tr>
									</thead>									
									<xsl:for-each select="Corridor">
									 <xsl:sort select="@name" order="ascending" data-type="text" />
									 <xsl:variable name="CorridorName" select="@name"/>											
													
                                                    <xsl:choose>
                                                        <xsl:when test="HVControl">
															<xsl:for-each select="HVControl">
																<xsl:if test="@controlType = 'CorridorPoint'">
																	<tr>
																		<td  colspan="1" align="left"><xsl:value-of select="$CorridorName"/></td>
																		<td  colspan="1" align="left"><xsl:value-of select="@controlParentName"/></td>
																		<td>&#xa0;</td>
																		<td>&#xa0;</td>
																		<td>&#xa0;</td>
																		<td>&#xa0;</td>	
																	</tr>
																</xsl:if>																
                                                            </xsl:for-each>																										
                                                        </xsl:when>
														<xsl:otherwise>
															<xsl:if test="(count(controlType/CorridorPoint/@controlParentName)= 0)">
																		<tr>
																			<td  colspan="1" align="left"><xsl:value-of select="$CorridorName"/></td>
																			<td colspan="1" align="left">Not a CorridorPointControl</td>
																			<td>&#xa0;</td>
																			<td>&#xa0;</td>
																			<td>&#xa0;</td>
																			<td>&#xa0;</td>	
																		</tr>
															</xsl:if>
														</xsl:otherwise> 
                                                    </xsl:choose>
													<xsl:choose>
															<xsl:when test="ClippingOption">
																<xsl:for-each select="ClippingOption">
																	<tr>
																		<td  colspan="1" align="left"><xsl:value-of select="$CorridorName"/></td>
																		<td>&#xa0;</td>
																		<td  colspan="1" align="left"><xsl:value-of select="@clippingCorridor"/></td>
																		<td>&#xa0;</td>	
																		<td>&#xa0;</td>
																		<td>&#xa0;</td>
																	</tr>
																</xsl:for-each>		
															</xsl:when>
														<xsl:otherwise>
                                                            <tr>
																<td  colspan="1" align="left"><xsl:value-of select="$CorridorName"/></td>
																<td>&#xa0;</td>
																<td colspan="1" align="left">No CorridorClipping</td>
																<td>&#xa0;</td>
																<td>&#xa0;</td>
																<td>&#xa0;</td>	                                                                
                                                            </tr>
                                                        </xsl:otherwise>
													</xsl:choose>
													<xsl:choose> 
														<xsl:when test="TargetAlias">
																	<xsl:for-each select="TargetAlias">
																			<xsl:for-each select="Alias">
																				<tr>
																					<td  colspan="1" align="left"><xsl:value-of select="$CorridorName"/></td>
																					<td>&#xa0;</td>
																					<td>&#xa0;</td>
																					<td  colspan="1" align="left"><xsl:value-of select="@name"/></td>
																					<td>&#xa0;</td>
																					<td>&#xa0;</td>
																				</tr>
																			</xsl:for-each>
																	</xsl:for-each>		
														</xsl:when>
														<xsl:otherwise>
                                                            <tr>
																<td  colspan="1" align="left"><xsl:value-of select="$CorridorName"/></td>
																<td>&#xa0;</td>
																<td>&#xa0;</td>
																<td colspan="1" align="left">No TargetAlias</td>
																<td>&#xa0;</td>
																<td>&#xa0;</td>	                                                                
                                                            </tr>
                                                        </xsl:otherwise>
													</xsl:choose>
													<xsl:choose> 
														<xsl:when test="TemplateDrop/Template/Components/Component/EndConditionTarget">
																<xsl:for-each select="TemplateDrop/Template/Components/Component/EndConditionTarget">
																	<xsl:if test="@targetType = 'AlignmentXYZ'">
																				<tr>
																					<td  colspan="1" align="left"><xsl:value-of select="$CorridorName"/></td>
																					<td>&#xa0;</td>
																					<td>&#xa0;</td>
																					<td>&#xa0;</td>
																					<td  colspan="1" align="left"><xsl:value-of select="@targetParentName"/></td>
																				</tr>
																	</xsl:if>
																	<xsl:if test="@targetType = 'AlignmentXY'">
																				<tr>
																					<td  colspan="1" align="left"><xsl:value-of select="$CorridorName"/></td>
																					<td>&#xa0;</td>
																					<td>&#xa0;</td>
																					<td>&#xa0;</td>
																					<td  colspan="1" align="left"><xsl:value-of select="@targetParentName"/></td>
																				</tr>
																	</xsl:if>
																	<xsl:if test="@targetType = 'AlignmentZ'">
																				<tr>
																					<td  colspan="1" align="left"><xsl:value-of select="$CorridorName"/></td>
																					<td>&#xa0;</td>
																					<td>&#xa0;</td>
																					<td>&#xa0;</td>
																					<td  colspan="1" align="left"><xsl:value-of select="@targetParentName"/></td>
																				</tr>
																	</xsl:if>		
																</xsl:for-each>		
														</xsl:when>
														<xsl:otherwise>
                                                            <tr>
																<td  colspan="1" align="left"><xsl:value-of select="$CorridorName"/></td>
																<td>&#xa0;</td>
																<td>&#xa0;</td>
																<td>&#xa0;</td>
																<td colspan="1" align="left">No Alignment EC Target</td>
																<td>&#xa0;</td>	                                                                
                                                            </tr>
                                                        </xsl:otherwise>
													</xsl:choose>
													<xsl:choose> 
														<xsl:when test="TemplateDrop/Template/Components/Component/EndConditionTarget">
																<xsl:for-each select="TemplateDrop/Template/Components/Component/EndConditionTarget">
																	<xsl:if test="@targetType = 'StyleXYZ'">
																				<tr>
																					<td  colspan="1" align="left"><xsl:value-of select="$CorridorName"/></td>
																					<td>&#xa0;</td>
																					<td>&#xa0;</td>
																					<td>&#xa0;</td>
																					<td  colspan="1" align="left"><xsl:value-of select="@targetName"/> = <xsl:value-of select="@targetType"/></td>
																				</tr>
																	</xsl:if>
																	<xsl:if test="@targetType = 'StyleXY'">
																				<tr>
																					<td  colspan="1" align="left"><xsl:value-of select="$CorridorName"/></td>
																					<td>&#xa0;</td>
																					<td>&#xa0;</td>
																					<td>&#xa0;</td>
																					<td  colspan="1" align="left"><xsl:value-of select="@targetName"/> = <xsl:value-of select="@targetType"/></td>
																				</tr>
																	</xsl:if>
																	<xsl:if test="@targetType = 'StyleZ'">
																				<tr>
																					<td  colspan="1" align="left"><xsl:value-of select="$CorridorName"/></td>
																					<td>&#xa0;</td>
																					<td>&#xa0;</td>
																					<td>&#xa0;</td>
																					<td  colspan="1" align="left"><xsl:value-of select="@targetName"/> = <xsl:value-of select="@targetType"/></td>
																				</tr>
																	</xsl:if>		
																</xsl:for-each>		
														</xsl:when>
														<xsl:otherwise>
                                                            <tr>
																<td  colspan="1" align="left"><xsl:value-of select="$CorridorName"/></td>
																<td>&#xa0;</td>
																<td>&#xa0;</td>
																<td>&#xa0;</td>
																<td colspan="1" align="left">No Style Target</td>
																<td>&#xa0;</td>	                                                                
                                                            </tr>
                                                        </xsl:otherwise>
													</xsl:choose>													
													<xsl:choose>
                                                        <xsl:when test="TemplateDrop/Template/Points/Point/@styleConstraintMode">
															<xsl:for-each select="TemplateDrop/Template/Points/Point">
																<xsl:sort select="@styleConstraintName" order="ascending" data-type="text" />
																	<xsl:if test="@styleConstraintMode">
																				<tr>
																					<td  colspan="1" align="left"><xsl:value-of select="$CorridorName"/></td>
																					<td>&#xa0;</td>
																					<td>&#xa0;</td>
																					<td>&#xa0;</td>
																					<td>&#xa0;</td>	
																					 <td  colspan="1" align="left"><xsl:value-of select="@styleConstraintName"/></td> 
																				</tr>
																	</xsl:if>														
															</xsl:for-each>																
														</xsl:when>					
														 <xsl:otherwise>
                                                            <tr>
																<td  colspan="1" align="left"><xsl:value-of select="$CorridorName"/></td>
																<td>&#xa0;</td>
																<td>&#xa0;</td>
																<td>&#xa0;</td>
																<td>&#xa0;</td>	
                                                                <td colspan="1" align="left">No Style Constraint</td>
                                                            </tr>
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                           
                                      </xsl:for-each>								
                                </table>
                        </xsl:for-each>
                </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must open a Roadway Design file by selecting <em>File &gt; Open</em> on the <em>Report 
                Browser</em> menu and setting the <em>Files of type</em> field to <em>Roadway Design 
                (*.ird)</em>.
            </p>
            <p class="normal1" lang="en">
                You must also have at least one corridor defined in the <em>Modeler &gt; Roadway Designer 
                &gt; Corridor &gt; Corridor Manager</em> command to get results from this report.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
